//
// zdict - simple dictionary viewer
// Copyright (C) 2004 Bryan Beicker <tokiko@tokiko.net>
//
// This file is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License (Version 2)
// as published by the Free Software Foundation.
//
// This file is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//

#include <gtk/gtk.h>		// gtk
#include <string.h>		// strlen(), strcmp()
#include "eng.h"
#include "jap.h"
#include "main.h"


void main_load()
{
	gtk_range_set_increments(GTK_RANGE(scroll), 1, 1024);
	
	gtk_combo_box_append_text(GTK_COMBO_BOX(combo), "English to Japanese");
	gtk_combo_box_append_text(GTK_COMBO_BOX(combo), "Japanese to English");
	gtk_combo_box_set_active(GTK_COMBO_BOX(combo), 0);
}


//
// window manager is trying to close the window
//
gboolean main_unload(GtkWidget * window, GdkEvent * event, gpointer data)
{
	// let the window close
	return FALSE;
}


//
// exit the program when the window dies
//
void main_destroy(GtkWidget * window, gpointer data)
{
	gtk_main_quit();
}


//
// display about box
//
gboolean icon_click(GtkWidget * widget, GdkEventButton * event, gpointer data)
{
	GtkWidget * window;
	
	window = about_create();
	gtk_widget_show(window);
	
	// we handled the event
	return TRUE;
}


//
// change the dictionary
//
void combo_change(GtkComboBox * widget, gpointer data)
{
	int lang;
	GtkAdjustment * a;

	lang = gtk_combo_box_get_active(widget);
	if (lang == 0) {
		gtk_range_set_range(GTK_RANGE(scroll), 0, ENG_NUM - 10);
	} else {
		gtk_range_set_range(GTK_RANGE(scroll), 0, JAP_NUM - 10);
	}
	
	gtk_range_set_value(GTK_RANGE(scroll), 0);
	a = gtk_range_get_adjustment(GTK_RANGE(scroll));
	gtk_adjustment_value_changed(a);
	gtk_adjustment_changed(a);
	
	gtk_entry_set_text(GTK_ENTRY(search), "");
}


//
// refresh the list
//
void scroll_value_changed(GtkVScrollbar * widget, gpointer data)
{
	gdouble d;
	int v;
	int i;
	int lang;
	
	lang = gtk_combo_box_get_active(GTK_COMBO_BOX(combo));
	d = gtk_range_get_value(GTK_RANGE(widget));
	v = d;
	
	if (lang == 0) {
		for (i = 0; i < 10; i++) {
			gtk_entry_set_text(GTK_ENTRY(name[i]), eng[i + v][0]);
			gtk_entry_set_text(GTK_ENTRY(value[i]), eng[i + v][1]);
		}
	} else {
		for (i = 0; i < 10; i++) {
			gtk_entry_set_text(GTK_ENTRY(name[i]), jap[i + v][0]);
			gtk_entry_set_text(GTK_ENTRY(value[i]), jap[i + v][1]);
		}
	}

}


//
// search for a string
//
void search_changed(GtkEntry * widget, gpointer data)
{
	const gchar * text;
	int lang;
	int i;
	
	text = gtk_entry_get_text(widget);
	if (strlen(text) == 0) {
		return;
	}

	lang = gtk_combo_box_get_active(GTK_COMBO_BOX(combo));
	if (lang == 0) {
		for (i = 0; i < ENG_NUM; i++) {
			if (strcmp(text, eng[i][0]) <= 0) {
				if (i > ENG_NUM - 10) {
					i = ENG_NUM - 10;
				}
				gtk_range_set_value(GTK_RANGE(scroll), i);
				gtk_adjustment_value_changed(gtk_range_get_adjustment(GTK_RANGE(scroll)));
				return;
			}
		}
	} else {
		for (i = 0; i < JAP_NUM; i++) {
			if (strcmp(text, jap[i][0]) <= 0) {
				if (i > JAP_NUM - 10) {
					i = JAP_NUM - 10;
				}
				gtk_range_set_value(GTK_RANGE(scroll), i);
				gtk_adjustment_value_changed(gtk_range_get_adjustment(GTK_RANGE(scroll)));
				return;
			}
		}
	}	
}
